==> flutter_webview_desktop-0.0.3-dev.tar.gz: windows/webview_render.cc <==
#include "webview_bridge.h"
#include "include/wrapper/cef_helpers.h"
void WebviewClient::GetViewRect(CefRefPtr<CefBrowser> browser, CefRect &rect)
{
    CEF_REQUIRE_UI_THREAD();

    rect.Set(0, 0, texture_size_.width, texture_size_.height);
}
void WebviewClient::OnPaint(CefRefPtr<CefBrowser> browser,
                            PaintElementType type,
                            const RectList &dirtyRects,
                            const void *buffer,
                            int width,
                            int height)
{

    uint32_t stride = width * 4;
    size_t cb = stride * height;

    if (!pixel_buffer_ || pixel_buffer_->width != width ||
        pixel_buffer_->height != height)
    {
        if (!pixel_buffer_)
        {
            pixel_buffer_ = std::make_unique<FlutterDesktopPixelBuffer>();
            sw_buffer_ = std::shared_ptr<uint8_t>((uint8_t *)malloc(cb), free);
        }
        pixel_buffer_->width = width;
        pixel_buffer_->height = height;
        sw_buffer_.reset(new uint8_t[cb]);
        pixel_buffer_->buffer = sw_buffer_.get();
    }
    if (sw_buffer_ && buffer)
    {

        int32_t *dest = reinterpret_cast<int32_t *>(sw_buffer_.get());
        int32_t *src = (int32_t *)buffer;
        int32_t rgba;
        int32_t bgra;
        int length = width * height;
        for (int i = 0; i < length; i++)
        {
            bgra = src[i];
            // BGRA in hex = 0xAARRGGBB.
            rgba = (bgra & 0x00ff0000) >> 16    // Red >> Blue.
                   | (bgra & 0xff00ff00)        // Green Alpha.
                   | (bgra & 0x000000ff) << 16; // Blue >> Red.
            dest[i] = rgba;
        }
    }
    if (frame_available_)
    {
        frame_available_();
    }
}

void WebviewClient::OnPopupShow(CefRefPtr<CefBrowser> browser, bool show)
{
    ::MessageBox(NULL, L"OnPopupShow", L"Tip", MB_OK);
    if (show)
    {
        ::MessageBox(NULL, L"OnPopupShow is show ", L"Tip", MB_OK);
    }
}

==> flutter_webview_desktop-0.0.8-dev.tar.gz: windows/webview_render.cc <==
#include "webview_bridge.h"
#include "include/wrapper/cef_helpers.h"
void WebviewClient::GetViewRect(CefRefPtr<CefBrowser> browser, CefRect &rect)
{
    CEF_REQUIRE_UI_THREAD();

    rect.Set(0, 0, texture_size_.width * texture_size_.devicePixelRatio, texture_size_.height * texture_size_.devicePixelRatio);
}
void WebviewClient::OnPaint(CefRefPtr<CefBrowser> browser,
                            PaintElementType type,
                            const RectList &dirtyRects,
                            const void *buffer,
                            int width,
                            int height)
{

    uint32_t stride = width * 4;
    size_t cb = stride * height;

    if (!pixel_buffer_ || pixel_buffer_->width != width ||
        pixel_buffer_->height != height)
    {
        if (!pixel_buffer_)
        {
            pixel_buffer_ = std::make_unique<FlutterDesktopPixelBuffer>();
            sw_buffer_ = std::shared_ptr<uint8_t>((uint8_t *)malloc(cb), free);
        }
        pixel_buffer_->width = width;
        pixel_buffer_->height = height;
        sw_buffer_.reset(new uint8_t[cb]);
        pixel_buffer_->buffer = sw_buffer_.get();
    }
    if (sw_buffer_ && buffer)
    {

        int32_t *dest = reinterpret_cast<int32_t *>(sw_buffer_.get());
        int32_t *src = (int32_t *)buffer;
        int32_t rgba;
        int32_t bgra;
        int length = width * height;
        for (int i = 0; i < length; i++)
        {
            bgra = src[i];
            // BGRA in hex = 0xAARRGGBB.
            rgba = (bgra & 0x00ff0000) >> 16    // Red >> Blue.
                   | (bgra & 0xff00ff00)        // Green Alpha.
                   | (bgra & 0x000000ff) << 16; // Blue >> Red.
            dest[i] = rgba;
        }
    }
    if (frame_available_)
    {
        frame_available_();
    }
}

void WebviewClient::OnPopupShow(CefRefPtr<CefBrowser> browser, bool show)
{
    // ::MessageBox(NULL, L"OnPopupShow", L"Tip", MB_OK);
    // if (show)
    // {
    //     ::MessageBox(NULL, L"OnPopupShow is show ", L"Tip", MB_OK);
    // }
}
